import { OnModuleInit } from '@nestjs/common';
import {
  ConnectedSocket,
  MessageBody,
  SubscribeMessage,
  WebSocketGateway,
  WebSocketServer,
} from '@nestjs/websockets';
import { Server, Socket } from 'socket.io';

@WebSocketGateway({
  cors: {
    origin: ['http://localhost:3000'],
  },
})
export class MyGateway implements OnModuleInit {
  @WebSocketServer()
  server: Server;

  onModuleInit() {
    this.server.on('connection', (socket) => {
      console.log('Connected Socket ID', socket.id);
    });
  }

  @SubscribeMessage('send_changed_data')
  onSendChangedData(@MessageBody() body: any, @ConnectedSocket() client: Socket) {
    console.log(`Send Changed Data from ${client.id}`);
    console.log('Body: ', body);
    this.server.emit('received_changed_data', body);
  }

}